/**
Copyright (c) 2006-2008 by Matjaz Kovac

Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do 
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.

\file App.cpp
\author Matjaž Kovač
\brief Main program file
*/

#define DEBUG 1
#include <Debug.h>
#include "App.h"
#include "BrowserWindow.h"
#include "SettingsWindow.h"
#include <Alert.h>
#include <Path.h>
#include <File.h>
#include <FindDirectory.h>


#define ABOUT_TEXT "Album (Code Name Aberration) v0.7a\n\nCopyright "B_UTF8_COPYRIGHT" 2006-2008 by Matjaž Kovač\n
This program is distributed under the terms of the MIT License (see LICENSE).\n
Contains software under the terms of the Be Sample Code License and the Open Tracker License.
Includes libexif EXIF extraction library, copyright "B_UTF8_COPYRIGHT" 2002 Lutz Müller under the terms of the GNU LGPL.
Includes libiptcdata IPTC manipulation library, copyright "B_UTF8_COPYRIGHT" 2005 David Moore under the terms of the GNU LGPL.\n
Recompiled on "__DATE__


int main(int, char**)
{
	new App();
	be_app->Run();
	delete be_app;
	return 0;
}


App::App():
	BApplication(APP_SIGNATURE)
{
	BWindow *fMain = new BrowserWindow(BRect(16, 32, 640, 480), "Album");
	fMain->Show();
	fSettings = new SettingsWindow(BRect(40, 40, 350, 350), _("Preferences"));
}


App::~App()
{
	//SavePreferences("Album_settings");
}


/** 
	Fires on B_ABOUT_REQUESTED.
*/
void App::AboutRequested()
{
    BAlert* box = new BAlert(_("About"), ABOUT_TEXT, _("Cool"));
    box->Go();
    // BAlert deleted itself.
}


void App::MessageReceived(BMessage *message)
{
    switch (message->what) {
		case CMD_SHOW_PREFS:
			if (fSettings->IsHidden())
				fSettings->Show();
			else
				fSettings->Activate();
			break;
		case CMD_UPDATE_PREFS:
			SavePreferences(message, "Album_settings");
			UpdatePreferences(message);
			break;
    	default:
    		BApplication::MessageReceived(message);
    }
}


/**
	All windows are operational.
*/ 
void App::ReadyToRun()
{
	BMessage prefs;
	prefs.AddInt32("load_options", 1);
	RestorePreferences(&prefs, "Album_settings");
	UpdatePreferences(&prefs);
}


/**
	Closes all windows and calls it a run.
*/
bool App::QuitRequested()
{
	// This better work...
	BWindow *window = NULL;
	while ((window = WindowAt(0))) {
		if (window->Lock())
			window->Quit();
		else break;
	}
	return true;
}

/**
	Restores user preferences.
*/
status_t App::RestorePreferences(BMessage *prefs, const char *name)
{
	BPath path;
	status_t status = find_directory(B_USER_SETTINGS_DIRECTORY, &path);
    if (status == B_OK) {
    	path.Append(name);
    	BFile file(path.Path(), B_READ_ONLY);
    	status = prefs->Unflatten(&file);
    	
    }
    return status;
}

/**
	Stores the preferences in the User Settings Directory.
*/
status_t App::SavePreferences(BMessage *prefs, const char *name)
{
	BPath path;
	status_t status = find_directory(B_USER_SETTINGS_DIRECTORY, &path);
    if (status == B_OK) {
    	path.Append(name);
    	BFile file(path.Path(), B_WRITE_ONLY | B_CREATE_FILE);
    	status = prefs->Flatten(&file);
    }
    return status;
}

/**
	Broadcasts a new preferences set to all windows.
*/
void App::UpdatePreferences(BMessage *message)
{
	//fPreferences = *message;
	message->what = MSG_PREFS_CHANGED;
	BWindow *window = NULL;
	for (int32 i = 0; (window = WindowAt(i)); i++) {
		window->PostMessage(message);		
	}
}