/**
\file EditableListView.cpp 
\brief EditableListView implementation and helpers.

Copyright (c) 2005-2006 by Matjaz Kovac

Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do 
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

#include <InterfaceKit.h>
#include <stdio.h>
#include "EditableListView.h"


ListViewEditBox::ListViewEditBox(BRect frame, const char *name, const char *text, BMessage *message, uint32 resizingMode, uint32 flags):
	BTextView(frame, name, frame.OffsetToSelf(0,0), resizingMode, flags)
{
	DisallowChar(B_ESCAPE);
	DisallowChar(B_TAB);
	MakeResizable(true);
	SetText(text);
	SetMessage(message);
}


/**
	The view is now fully functional.	
*/
void ListViewEditBox::AttachedToWindow()
{
	MakeFocus(true);
	SelectAll();
}

	
	
/**
	Handles keystrokes.
	Invokes a notification on B_ENTER
	Relays B_ESCAPE, B_UP_ARROW, B_DOWN_ARROW to its parent and gives up the focus (==self-destructs).
*/
void ListViewEditBox::KeyDown(const char *bytes, int32 numBytes)
{
    switch (bytes[0]) {
		case B_RETURN:
			if (Message()) {
				BMessage clone(*Message());
				clone.AddString("text", Text());				
				Invoke(&clone);
			}
			// Do this last.
			Parent()->MakeFocus(true);
			break;
	    case B_ESCAPE:
	    case B_UP_ARROW:
	    case B_DOWN_ARROW:
	        Parent()->KeyDown(bytes, numBytes);
	        // Do this last.
			Parent()->MakeFocus(true);
	        break;
	    default:
	        BTextView::KeyDown(bytes, numBytes);
    }
}


/**
	Self-destructs upon losing focus.
*/
void ListViewEditBox::MakeFocus(bool enable)
{
	BTextView::MakeFocus(enable);
	if (!enable) {
		RemoveSelf();
		delete this;
	}
}



