#ifndef IMAGEBROWSER_H_
#define IMAGEBROWSER_H_

#include "BufferedView.h"
#include "ImageBrowserItem.h"
#include "ObjectList.h"
#include "ImageLoader.h"

enum {
	CMD_REMOVE_SELECTED = 'rmSl',
	CMD_MARK_SELECTED = 'mkSl',
	CMD_SELECT_MARKED = 'slMk',
	CMD_UNMARK_ALL = 'uMrA',
	CMD_UNMARK_SELECTED = 'uMrk',
	CMD_INVOKE = 'invk',
	CMD_FILE_TRASH = 'trsh',
	MSG_ITEM_COUNT_CHANGED = 'ItCh',
	MSG_SELECTION_CHANGED = 'SelC'
};



class ImageBrowser: public BufferedView {
	public:
	
	ImageBrowser(BRect frame, const char *name, uint32 resize);
	virtual ~ImageBrowser();
	
	// Inherited
	virtual void AttachedToWindow();
	virtual void FrameResized(float width, float height);
	virtual void DrawOffscreen(BView *view, BRect update);
	virtual void KeyDown(const char *bytes, int32 numBytes);
	virtual void MessageReceived(BMessage *message);
	virtual void MouseDown(BPoint where);
	virtual void MouseMoved(BPoint point, uint32 transit, const BMessage *message);
	virtual void MouseUp(BPoint where);
	virtual void Pulse();

	bool AddItem(ImageBrowserItem *item);
	inline ImageBrowserItem* ItemAt(int32 index);
	inline int32 CountItems();
	
	void GetSelection(BMessage *message);
	void SelectItems(bool state, int32 from, int32 to);
	void DeleteSelected();
	void MarkItems(bool state, bool onlySelected);
	void SelectMarked();
	void SetColumns(int columns);
	void SetLabels(uint32 labels);
	inline uint32 Labels();
	void SetOrder(int order);
	void SetZoom(float scale);
	inline ImageLoader* Loader();

	private:

	void Arrange(BRegion *dirty = NULL);
	void RefsReceived(BMessage *message);
	void UpdateReceived(BMessage *message);
	void DeleteReceived(BMessage *message);
	void SelectionChanged();
	void ItemDragged(const BMessage *message);
	void ItemInvoked(BMessage *message);
	void NoticeReceived(BMessage *message);
	void NotifyOnProgress(BMessage *notice);
	void ShowContextMenu(BPoint origin, ImageBrowserItem *item);
	void FixupScrollbars(float maxWidth, float maxHeight);
	
	BObjectList<ImageBrowserItem> fItems;
	ImageLoader *fLoader;
	ImageBrowserItem *fLastSelected;
	BPoint fLastWhere;
	float fMaxWidth, fMaxHeight;
	float fZoom;
	int fSelCount;
	int fColumns;
	uint32 fOrder, fLabels;
	bool fMayDrag, fDoubleClicked, fAnimate, fUpdatePending;
};


// Inlines

uint32 ImageBrowser::Labels()
{
	return fLabels;
}

ImageLoader* ImageBrowser::Loader()
{
	return fLoader;
}

ImageBrowserItem* ImageBrowser::ItemAt(int32 index)
{
	return fItems.ItemAt(index);
}

int32 ImageBrowser::CountItems()
{
	return fItems.CountItems();
}

#endif

