#ifndef IMAGEBROWSERITEM_H_
#define IMAGEBROWSERITEM_H_

#include <Bitmap.h>
#include <Message.h>
#include <Entry.h>

enum {
	LABEL_NAME = 1,
	LABEL_SIZE = 2,
	LABEL_DATE = 4,
	LABEL_INDICATORS = 8,
	
	ITEM_EXIF = 1,
	ITEM_IPTC = 2,
	ITEM_TRASH = 4
};

class ImageBrowserItem {
	public:
	
	ImageBrowserItem(BRect frame);
	virtual ~ImageBrowserItem();
	
	virtual void DrawItem(BView *owner, uint32 mask = LABEL_NAME);
	virtual void Update(BView *owner, uint32 mask);
	inline BRect& Frame();
	void SetBitmap(BBitmap *bitmap);
	inline BBitmap* Bitmap() const;
	void SetFlags(uint32 flags);	
	inline int Flags();
	void SetSelected(bool enable);
	inline bool IsSelected();
	void SetMarked(bool enable);
	inline bool IsMarked();
	void SetIntensity(uint8 level);
	inline uint8 Intensity();
	void SetScale(float scale);
	inline float Scale();

	// File Metadata
	inline const char* Name() const;
	inline BMessage& Tags();
	inline BMessage& Attributes();
	inline const entry_ref& EntryRef() const;
	inline const off_t& Size() const;
	inline const time_t& TimeCreated() const;
	inline const time_t& TimeModified() const;
	
	// Comparison Functions
 	static int CmpSerial(const ImageBrowserItem *a, const ImageBrowserItem *b);
	static int CmpName(const ImageBrowserItem *a, const ImageBrowserItem *b);
	static int CmpSize(const ImageBrowserItem *a, const ImageBrowserItem *b);
	static int CmpTimeModified(const ImageBrowserItem *a, const ImageBrowserItem *b);

	// File Ops
	status_t WriteThumbnail(const char *attrname, uint32 type);
	status_t WriteTrackerIcon();
	status_t SetRef(entry_ref *ref);
	status_t MoveToTrash();
	
	private:
	static BBitmap *fIndicatorBmap[3];
	BBitmap *fBitmap;
	BRect fFrame;
	BMessage fTags, fAttr;
	rgb_color fBackColor;
	entry_ref fEntryRef;
	off_t fFileSize;
	time_t fCDate, fMDate;	
	float fScale;
	int fSerial, fFlags;
	bool fSelected:1, fMarked:1;
	uint8 fIntensity;
};


// Inlines

BRect& ImageBrowserItem::Frame()
{
	return fFrame;
}

BBitmap* ImageBrowserItem::Bitmap() const
{
	return fBitmap;
}

int ImageBrowserItem::Flags()
{
	return fFlags;
}

const char* ImageBrowserItem::Name() const
{
	return fEntryRef.name;
}

bool ImageBrowserItem::IsSelected()
{
	return fSelected;
}

bool ImageBrowserItem::IsMarked()
{
	return fMarked;
}

uint8 ImageBrowserItem::Intensity()
{
	return fIntensity;
}

float ImageBrowserItem::Scale()
{
	return fScale;
}

const entry_ref& ImageBrowserItem::EntryRef() const 
{
	return fEntryRef;
}

const off_t& ImageBrowserItem::Size() const
{
	return fFileSize;
}

const time_t& ImageBrowserItem::TimeCreated() const
{
	return fCDate;
}

const time_t& ImageBrowserItem::TimeModified() const
{
	return fMDate;
}


BMessage& ImageBrowserItem::Tags()
{
	return fTags;
}

BMessage& ImageBrowserItem::Attributes()
{
	return fAttr;
}

#endif

