/**
Copyright (c) 2006-2008 by Matjaz Kovac

Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do 
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/
#ifndef IMAGELOADER_H_
#define IMAGELOADER_H_

#include <Entry.h>
#include <String.h>
#include <Looper.h>
#include <Message.h>
#include <Locker.h>
#include <Query.h>
#include <Node.h>
#include "ObjectList.h"

enum {
	CMD_LOADER_DELETE = 'ldRm',
	// Replies.
	MSG_LOADER_UPDATE = 'ldUp',
	MSG_LOADER_PROGRESS = 'ldPr',
	MSG_LOADER_DONE= 'ldEn',
	MSG_LOADER_DELETED = 'ldDl',
	LOAD_STATS = 1,
	LOAD_ATTRIBUTES = 2,
	LOAD_DATA = 4,
	//
	LOAD_OPT_TAGS = 1,
	LOAD_OPT_ALIAS = 2,
};


/// Monitored nodes
struct file_item {
	node_ref nodref;
	entry_ref entref;
	file_item(node_ref &node);
	static int cmp(const file_item *a, const file_item *b);
};


class ImageLoader : public BLooper
{
	public:
	
	ImageLoader(const char *name);
	~ImageLoader();
	virtual void MessageReceived(BMessage *message);
	void RefsReceived(BMessage *message);
	virtual status_t HandleRef(entry_ref *ref);
	virtual status_t HandleFile(entry_ref *ref);
	virtual status_t HandleDirectory(entry_ref *ref);
    virtual status_t HandleQuery(const char *predicate, BVolume *volume);
	void Stop();
	bool IsBusy();
	BBitmap* MakeImagePreview(entry_ref *ref);
	status_t ApplyTags(entry_ref *ref);
	virtual status_t LoadFile(entry_ref *ref, BMessage *reply, uint32 mode = 0xff);
	void SetThumbnailSize(float width, float height);
	

	int32 fLoadOptions;
	BMessage fAliases;
	
	private:

	void NodeMonitorChange(BMessage *message);
	void DeleteReceived(BMessage *message);
	
	BObjectList<file_item> fItems;
	BLocker fLocker;
	bool fRunning;
	BQuery fQuery;
	int32 fTotal, fDone;
	float fThumbWidth, fThumbHeight;
	BString fReadAttr, fWriteAttr;
};

#endif