/**
\file Splitter.h
\brief Splitter class definitions.

Copyright (c) 2007 by Matjaz Kovac

Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do 
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

#ifndef _SPLITTER_H_
#define _SPLITTER_H_

#include <Control.h>

/// Splitter Type
enum {
	SPLITTER_RIGHT = 0,
	SPLITTER_BOTTOM = 1,
};

/// Split-view control
class Splitter : public BControl
{
	public:
	
	Splitter(float size, const char *name, uint32 type = SPLITTER_RIGHT);
	virtual void AttachedToWindow();
	virtual void Draw(BRect frame);
	virtual void FrameResized(float width, float height);
	virtual void FrameMoved(BPoint point);

	virtual void MouseDown(BPoint where);	
	virtual void MouseUp(BPoint where);	
	virtual void MouseMoved(BPoint point, uint32 transit, const BMessage *message);
	void SetLimits(float min, float max);	
	
	private:
	
	uint32 fMode;
	BPoint fGrabPoint;
	bool fDragged;
	float fMin, fMax;
	int fSnap;
};


#endif